==> nextcloud-24.0.5.tgz: nextcloud/apps/systemtags/l10n/de.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Schlagwortbezeichnung ist leer",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag …" : "Schlagwort wählen …",
    "System tag %1$s added by the system" : "System-Tag %1$s vom System hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "System tag %1$s removed by the system" : "System-Tag %1$s wurde vom System entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat das System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Du hast das System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Du hast den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Du hast den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Du hast den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat den System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat den System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hat den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "System tag %2$s was added to %1$s by the system" : "System-Tag %2$s wurde vom System %1$s hinzugefügt",
    "System tag {systemtag} was added to {file} by the system" : "System-Tag {systemtag} wurde {file} vom System hinzugefügrt",
    "You added system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Du hast den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat den System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "System tag %2$s was removed from %1$s by the system" : "System-Tag %2$s wurde vom System aus %1$s entfernt",
    "System tag {systemtag} was removed from {file} by the system" : "System-Tag {systemtag} wurde vom System von {file} entfernt",
    "You removed system tag %2$s from %1$s" : "Du hast den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Du hast den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat das den System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei wurden geändert",
    "Tags" : "Tags",
    "All tagged %s …" : "Alle Schlagwörter %s hinzugefügt ....",
    "tagged %s" : "Schlagwort %s hinzugefügt",
    "Collaborative tags" : "Kollaborative Tags",
    "Collaborative tagging functionality which shares tags among users." : "Kollaborative Tags Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt. Sehr gut für Gruppen.\n(Wenn du ein Anbieter mit einer Mehrkundeninstallation bist, so ist angeraten diese App zu deaktiveren, da die Schlagworte mit allen Kunden geteilt werden.)",
    "Tagged files" : "Mit Tags versehene Dateien",
    "Select tags to filter by" : "Wähle Tags nach denen gefilter werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wähle die Tags nach denen gefiltert werden soll",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Öffentliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Create a new tag" : "Neues Schlagwort erstellen",
    "Name" : "Name",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/systemtags/l10n/de.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Schlagwortbezeichnung ist leer",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag …" : "Schlagwort wählen …",
    "System tag %1$s added by the system" : "System-Tag %1$s vom System hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "System tag %1$s removed by the system" : "System-Tag %1$s wurde vom System entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat das System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Du hast das System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Du hast den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Du hast den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Du hast den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat den System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat den System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hat den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "System tag %2$s was added to %1$s by the system" : "System-Tag %2$s wurde vom System %1$s hinzugefügt",
    "System tag {systemtag} was added to {file} by the system" : "System-Tag {systemtag} wurde {file} vom System hinzugefügt",
    "You added system tag %2$s to %1$s" : "Du hast den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Du hast den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat den System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "System tag %2$s was removed from %1$s by the system" : "System-Tag %2$s wurde vom System aus %1$s entfernt",
    "System tag {systemtag} was removed from {file} by the system" : "System-Tag {systemtag} wurde vom System von {file} entfernt",
    "You removed system tag %2$s from %1$s" : "Du hast den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Du hast den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat das den System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei wurden geändert",
    "Tags" : "Tags",
    "All tagged %s …" : "Alle Schlagwörter %s hinzugefügt ....",
    "tagged %s" : "Schlagwort %s hinzugefügt",
    "Collaborative tags" : "Kollaborative Tags",
    "Collaborative tagging functionality which shares tags among users." : "Kollaborative Tags Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt. Sehr gut für Gruppen.\n(Wenn du ein Anbieter mit einer Mehrkundeninstallation bist, so ist angeraten diese App zu deaktiveren, da die Schlagworte mit allen Kunden geteilt werden.)",
    "Tagged files" : "Mit Tags versehene Dateien",
    "Select tags to filter by" : "Wähle Tags nach denen gefilter werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wähle die Tags nach denen gefiltert werden soll",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Öffentliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Create a new tag" : "Neues Schlagwort erstellen",
    "Name" : "Name",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");
